/*
 * Velleman K8048 Programmer for FreeBSD and others.
 *
 * Copyright (c) 2005-2007 Darron Broad
 * All rights reserved.
 *
 * Licensed under the terms of the BSD license, see file LICENSE
 * for details.
 *
 * $Id: dotconf.c,v 1.9 2007/05/24 23:00:36 darron Exp $
 */

#include "k8048.h"

/******************************************************************************
 * DOT CONFIG FUNCTIONS
 *****************************************************************************/

void
getconf(struct k8048 *k)
{
    char line[STRLEN], *homedir, *username;
    FILE *f1;

    /* clear config */
    bzero(k, sizeof(k));

    /* default to current working directory */
    snprintf(k->dotfile, STRLEN, "%s/%s", getcwd(line, STRLEN), DOTFILENAME);
    if(access(k->dotfile, R_OK) < 0)
    {
        /* try home dir */
        homedir= getenv("HOME");
        if(homedir!=NULL)
            snprintf(k->dotfile, STRLEN, "%s/%s", homedir, DOTFILENAME);
        else
        {
            /* try default home dir */
            username= getenv("USER");
            if(username!=NULL)
                snprintf(k->dotfile, STRLEN, "/home/%s/%s", username, DOTFILENAME);
        }
    }

    /* load dotfile if present */
    f1= fopen(k->dotfile, "rb");
    if(f1!=NULL)
    {
        while( fgets(line, STRLEN, f1) != NULL)
        {
            line[ strlen(line) - 1]= '\0';

            if(mystrcasestr(line, "DEVICE=")==line)
                strncpy(k->device, &line[7], STRMAX);

            else if(mystrcasestr(line, "BITRULES=")==line)
                k->flags= strtoul(&line[9], NULL, 0);
        }
        fclose(f1);
    }
    else /* Defaults */
    {
        snprintf(k->dotfile, STRLEN, "Default (override in %s)", DOTFILENAME);
        strncpy(k->device, SERIAL_DEVICE, STRMAX);
        k->flags = K8048;
    }
}
